@@ -5,6 +5,7 @@ from typing import List, Optional
 from .config_values import ConfigValues
 from .drawing_machine import DrawingMachine
 from ..abstract.fortune import FortuneAbstract
+from ..abstract.fortune_data import FortuneData
 from ..abstract.fortune_source import FortuneSource
 from .indexer import Indexer
 from random import randrange
@@ -14,10 +15,6 @@ from logging import Logger
 class Fortune(FortuneAbstract):
 
     SEPARATOR: str = '%\n'
-    # logger: Logger
-    # config: ConfigValues
-    # indexer: Indexer
-    # drawing_machine: DrawingMachine
 
     def __init__(self,
                  logger: Optional[Logger],
@@ -32,24 +29,43 @@ class Fortune(FortuneAbstract):
         self.validators = validators
         self.drawing_machine = drawing_machine
 
-    def get(self, sources: Optional[List[FortuneSource]] = None) -> str:
+    def get(self, sources: Optional[List[FortuneSource]] = None) -> FortuneData:
         validated_list = self._validate(sources)
         source = self._chose_source(validated_list)
         if source is None:
             raise ValueError('ERROR: Source is empty :(')
-        fortune_str = self.get_from_path(source.source)
-        return fortune_str
+        result_with_full_path_to_source: FortuneData = self._get_from_source(source.source)
 
-    def get_from_path(self, path: str) -> str:
-        if os.path.isdir(path):
-            return self._get_from_dir(path)
-        elif os.path.isfile(path):
-            return self._get_from_file(path)
-        raise Exception(f"Path {path} is not a file or directory")
+        return self._remove_root_path_from_source(result_with_full_path_to_source)
+
+    def _remove_root_path_from_source(self, fortune_data: FortuneData) -> FortuneData:
+        source = fortune_data.file
+        source = source.replace(self.config.root_path, '', 1)
+        if source[0] == '/':
+            source = source[1:]
+        return FortuneData(
+            fortune_data.fortune,
+            source,
+            fortune_data.index
+        )
+
+    def _get_from_source(self, source: str) -> FortuneData:
+        full_path: str = self.config.root_path
+        if source:
+            if full_path[-1] == '/':
+                full_path += source
+            else:
+                full_path += f"/{source}"
+
+        if os.path.isdir(full_path):
+            return self._get_from_dir(full_path)
+        elif os.path.isfile(full_path):
+            return self._get_from_file(full_path)
+        raise Exception(f"Cannot find db: {source}")
 
     def _chose_source(self, sources):
         if sources is None or sources == []:
-            result = FortuneSource(self.config.root_path)
+            result = FortuneSource('')
         elif self.drawing_machine is not None:
             result = self.drawing_machine.get(sources)
         else:
@@ -59,7 +75,7 @@ class Fortune(FortuneAbstract):
     def _validate(self, sources: Optional[List[FortuneSource]] = None) -> List[FortuneSource]:
         result = sources
         for validator in self.validators:
-            result = validator.validate(result)
+            result = validator.validate(result, self.config)
         return result
 
     def _chose_path(self, sources: Optional[List[FortuneSource]] = None):
@@ -72,17 +88,18 @@ class Fortune(FortuneAbstract):
 
         return result
 
-    def _get_from_file(self, file: str) -> str:
+    def _get_from_file(self, file: str) -> FortuneData:
         index = self.indexer.index(file)
         i = randrange(0, len(index.indices))
-        return self._read_fortune(file, index.indices[i])
+        fortune: str = self._read_fortune(file, index.indices[i])
+        return FortuneData(fortune, file, i)
 
-    def _get_from_dir(self, path: str) -> str:
+    def _get_from_dir(self, path: str) -> FortuneData:
         files = self._all_files_in_directory(path)
         if len(files) > 0:
             i = randrange(0, len(files))
             return self._get_from_file(files[i])
-        return ''
+        raise AttributeError('Cannot find any fortunes dbs in provided directory')
 
     def _all_files_in_directory(self, path: str) -> List[str]:
         list_of_files = []
@@ -93,6 +110,7 @@ class Fortune(FortuneAbstract):
         return list_of_files
 
     def _file_is_fortune_db(self, file: str) -> bool:
+        """FIXME: probably it should ignore only 'indices' files (right now it also will ignore files like debian.pl)"""
         result = True
         filename, file_extension = os.path.splitext(file)
         if file_extension:
@@ -111,4 +129,3 @@ class Fortune(FortuneAbstract):
             else:
                 fortune_end = True
         return result
-
